@@ -1,7 +1,7 @@
 from pychonet.EchonetInstance import EchonetInstance
 
 class HomeSolarPower(EchonetInstance):
-    def __init__(self, host, api_connector instance = 0x1):
+    def __init__(self, host, api_connector, instance = 0x1):
         self.eojgc = 0x02
         self.eojcc = 0x79
         EchonetInstance.__init__(self, host, self._eojgc, self._eojcc, instance, api_connector)
