@@ -161,61 +161,61 @@ def _0290B1(edt):
     }
     return values.get(op_mode, "invalid_setting")
 
-EPC_FUNCTIONS = {
-    0x00: {
-        0x11:{
-            0xE0: _0011E0,
-            0XE1: _int
-        }
-    },
-    0x01: {
-        0x30:{
-        	0xA0: _0130A0,
-            0xA1: _0130A1,
-            0xA3: _0130A3,
-            0xA4: _0130A4,
-            0xA5: _0130A5,
-            0xAA: _0130AA,
-            0xB0: _0130B0,
-            0xB3: _int,
-            0xBB: _int,
-            0xBE: _int
-        }
-    },
-    0x02: {
-        0x60: {
-            0xE0: _0260EO
-        },
-        0x6F: {
-            0xE0: _026FEX,
-            0xE1: _026FEX,
-            0xE2: _026FEX,
-            0xE3: _026FE3,
-            0xE4: _026FE4,
-            0xE5: _026FE5,
-            0xE6: _026FE6,
-            0xE7: _026FE7
-        },
-        0x79: {
-            0xE0: _int,
-            0xE1: _int
-        },
-        0x7d: {
-            0xE4: _int,
-            0xCF: _int
-        },
-        0x88: {
-            0xd7: _int, #number of effective digits in culmative amout of energy
-            0xe0: _int, #measured culmative amount of electricity
-            0xe1: _0288E1, #multiplying factor
-            # 0xe2:
-            0xe5: _int,
-            0xe7: _0288E7, #measured instantaneous electric energy
-            0xe8: _0288E8, #measured instantanenous currents
-            0xea: _0288EA
-        },
-        0x90: {
-            0xB1: _0290B1
-        }
-    }
-}
+# EPC_FUNCTIONS = {
+#     0x00: {
+#         0x11:{
+#             0xE0: _0011E0,
+#             0XE1: _int
+#         }
+#     },
+#     0x01: {
+#         0x30:{
+#         	0xA0: _0130A0,
+#             0xA1: _0130A1,
+#             0xA3: _0130A3,
+#             0xA4: _0130A4,
+#             0xA5: _0130A5,
+#             0xAA: _0130AA,
+#             0xB0: _0130B0,
+#             0xB3: _int,
+#             0xBB: _int,
+#             0xBE: _int
+#         }
+#     },
+#     0x02: {
+#         0x60: {
+#             0xE0: _0260EO
+#         },
+#         0x6F: {
+#             0xE0: _026FEX,
+#             0xE1: _026FEX,
+#             0xE2: _026FEX,
+#             0xE3: _026FE3,
+#             0xE4: _026FE4,
+#             0xE5: _026FE5,
+#             0xE6: _026FE6,
+#             0xE7: _026FE7
+#         },
+#         0x79: {
+#             0xE0: _int,
+#             0xE1: _int
+#         },
+#         0x7d: {
+#             0xE4: _int,
+#             0xCF: _int
+#         },
+#         0x88: {
+#             0xd7: _int, #number of effective digits in culmative amout of energy
+#             0xe0: _int, #measured culmative amount of electricity
+#             0xe1: _0288E1, #multiplying factor
+#             # 0xe2:
+#             0xe5: _int,
+#             0xe7: _0288E7, #measured instantaneous electric energy
+#             0xe8: _0288E8, #measured instantanenous currents
+#             0xea: _0288EA
+#         },
+#         0x90: {
+#             0xB1: _0290B1
+#         }
+#     }
+# }
